package de.intevation.gnv.artifacts.services.requestobjects;

import java.util.Collection;

/**
 * This is the interface description of <code>MapService</code>. Currently,
 * there are four methods defined:<br>
 * <ol>
 *  <li>getID(): Returns the id of this service.</li>
 *  <li>getURL(): Returns the url used to call this service.</li>
 *  <li>getType(): Returns the service type.</li>
 *  <li>getLayer(): Returns a collection of layers contained in this service.
 *  </li>
 * </ol>
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface MapService {


    /**
     * Returns the id of this Service.
     * @return the id of this service.
     */
    String getID();

    /**
     * Returns the Url under which this service is available.
     * @return the url under which this service is available.
     */
    String getURL();

    /**
     * Returns the service type
     * @return the service type.
     */
    String getType();

    /**
     * Returns the Layer which belongs to this Service.
     * @return a collection of layers contained in this service.
     */
    Collection<Layer> getLayer();

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
